BEL Commons Documentation
=========================
.. toctree::
   :maxdepth: 2

   installation
   docker
   pages
   configuration

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
